@@ -15,7 +15,8 @@ agent_proxy_port=38080
 container_cidr=$AEMBIT_DOCKER_CONTAINER_CIDR
 # https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16
 azure_platform_resources_ip="168.63.129.16"
-aws_imds_ip="169.254.169.254"
+# IP of the cloud-provider metadata services.
+imds_ip="169.254.169.254"
 
 # Rule Chains
 aembit_raw_PREROUTING=aembit_raw_PREROUTING
@@ -302,7 +303,7 @@ function redirect_outbound_tcp_traffic_to_ap() {
     # Ignore outbound traffic to the Azure communication channel.
     # See https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16.
     add_ipv4_rule nat "${aembit_nat_OUTPUT}" -p tcp --destination "${azure_platform_resources_ip}" -j RETURN
-    add_ipv4_rule nat "${aembit_nat_OUTPUT}" -p tcp --destination "${aws_imds_ip}" -j RETURN
+    add_ipv4_rule nat "${aembit_nat_OUTPUT}" -p tcp --destination "${imds_ip}" -j RETURN
 
     if [ -z "${AEMBIT_STEERING_ALLOWED_HOSTS}" ]; then
         # Redirect all new TCP connections to the Agent Proxy if we didn't specify custom steering.
